src/cpu: Fix spelling of MTTR to MTRR

Change-Id: Ia4718ac31a5b2bd12f8cda5e107aa878d74d2a03
Signed-off-by: Paul Menzel <paulepanter@users.sourceforge.net>
Reviewed-on: http://review.coreboot.org/4805
Tested-by: build bot (Jenkins)
Reviewed-by: Alexandru Gagniuc <mr.nuke.me@gmail.com>
diff --git a/src/cpu/x86/mtrr/mtrr.c b/src/cpu/x86/mtrr/mtrr.c
index dd404a8..dbedf0f 100644
--- a/src/cpu/x86/mtrr/mtrr.c
+++ b/src/cpu/x86/mtrr/mtrr.c
@@ -454,7 +454,7 @@
 	if (var_state->mtrr_index >= bios_mtrrs)
 		printk(BIOS_WARNING, "Taking a reserved OS MTRR.\n");
 	if (var_state->mtrr_index >= total_mtrrs) {
-		printk(BIOS_ERR, "ERROR: Not enough MTTRs available!\n");
+		printk(BIOS_ERR, "ERROR: Not enough MTRRs available!\n");
 		return;
 	}
 
@@ -670,7 +670,7 @@
 	struct var_mtrr_state var_state;
 
 	/* The default MTRR cacheability type is determined by calculating
 	 * the number of MTTRs required for each MTTR type as if it was the
 	 * default. */
 	var_state.addr_space = addr_space;
 	var_state.above4gb = above4gb;
@@ -776,7 +776,7 @@
 			calc_var_mtrrs_without_hole(&var_state, r);
 	}
 
 	/* Clear all remaining variable MTTRs. */
 	for (i = var_state.mtrr_index; i < total_mtrrs; i++)
 		clear_var_mtrr(i);
 }
@@ -670,7 +670,7 @@
 
 	/* The default MTRR cacheability type is determined by calculating
-	 * the number of MTTRs required for each MTTR type as if it was the
+	 * the number of MTRRs required for each MTRR type as if it was the
 	 * default. */
 	var_state.addr_space = addr_space;
@@ -776,7 +776,7 @@
 	}
 
-	/* Clear all remaining variable MTTRs. */
+	/* Clear all remaining variable MTRRs. */
 	for (i = var_state.mtrr_index; i < total_mtrrs; i++)
 		clear_var_mtrr(i);